@@ -4,13 +4,25 @@ mat_split<- function(mat,nchunk){
   
   #case when input is number of chunks 
   if (length(nchunk) == 1) {
-    nc=floor(n/nchunk)
-    seq.chu=seq(from=1,to=n,by=nc-1)
-    seq.chu[nchunk+1] = n
+    # seq.chu[nchunk]=n 
+    # print(nc)
+    
+    
+    seq.chu=floor(seq(from=1,to=n,length.out =nchunk+1))
+    
+    
+    
+    # seq.chu[nchunk]=n 
+    #seq.chu=seq.chu[1:nchunk]
+    # print(length(seq.chu))
+    
+    
+    #  print(seq.chu)
+    # print(length(seq.chu))
   }
   #case when input is specific block sizes
   if (length(nchunk) > 1){
-  #  nc = length(nchunk)
+    #  nc = length(nchunk)
     seq.chu=0
     seq.chu=c(seq.chu,cumsum(nchunk))+1
     #fix last value
@@ -22,12 +34,17 @@ mat_split<- function(mat,nchunk){
   if (kk > 2)
   {
     mat.story[[1]]=mat[1:seq.chu[2],]
-  
+    
     for(k in 2:(kk-1)){
+      
       a=(seq.chu[k]+1)
       b=(seq.chu[k+1])
+      # print("a")
+      # print(a)
+      # print("b")
+      # print(b)
       mat.story[[k]]=mat[a : b, ]
-      }
+    }
     
   } else { #case of a single chunk
     mat.story[[1]] = mat  
@@ -37,8 +54,3 @@ mat_split<- function(mat,nchunk){
   
   out
 }
-
-
-#     mat.story[[2]]=mat2[92 : 181, ]
-#print(mat.story)
-#
